@@ -15,17 +15,22 @@ def init_permissions():
     """
     try:
         # Get or Create the default group
-        default_group, created = Group.objects.get_or_create(name=main_rights.default_group)
+        default_group, created = Group.objects.get_or_create(
+            name=main_rights.default_group
+        )
 
         # Get curate permissions
-        curate_access_perm = Permission.objects.get(codename=curate_rights.curate_access)
+        curate_access_perm = Permission.objects.get(
+            codename=curate_rights.curate_access
+        )
         curate_view_data_save_repo_perm = Permission.objects.get(
             codename=curate_rights.curate_view_data_save_repo
         )
 
         # Add permissions to default group
-        default_group.permissions.add(curate_access_perm,
-                                      curate_view_data_save_repo_perm)
+        default_group.permissions.add(
+            curate_access_perm, curate_view_data_save_repo_perm
+        )
 
     except Exception as e:
         logger.error("Impossible to init curate permissions: %s" % str(e))
